jupyterlab_pygments: Pygments theme using JupyterLab CSS variables
==================================================================

Description
-----------

Pygments theme using JupyterLab CSS variables

License
-------

BSD

Upstream Contact
----------------

https://pypi.org/project/jupyterlab-pygments/

